==> affected_by_promotion-8.x-1.0.zip: affected_by_promotion/tests/src/Unit/DummyPromotionBase.php <==
<?php

namespace Drupal\Tests\affected_by_promotion\Unit;

use Drupal\commerce_promotion\Entity\PromotionInterface;
use Drupal\commerce_promotion\Plugin\Commerce\PromotionOffer\PromotionOfferInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class DummyPromotionBase.
 */
abstract class DummyPromotionBase implements PromotionOfferInterface {

  /**
   * {@inheritdoc}
   */
  public function getConfiguration() {
    // TODO: Implement getConfiguration() method.
  }

  /**
   * {@inheritdoc}
   */
  public function setConfiguration(array $configuration) {
    // TODO: Implement setConfiguration() method.
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    // TODO: Implement defaultConfiguration() method.
  }

  /**
   * {@inheritdoc}
   */
  public function calculateDependencies() {
    // TODO: Implement calculateDependencies() method.
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(
    array $form,
    FormStateInterface $form_state
  ) {
    // TODO: Implement buildConfigurationForm() method.
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(
    array &$form,
    FormStateInterface $form_state
  ) {
    // TODO: Implement validateConfigurationForm() method.
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(
    array &$form,
    FormStateInterface $form_state
  ) {
    // TODO: Implement submitConfigurationForm() method.
  }

  /**
   * {@inheritdoc}
   */
  public function getPluginId() {
    // TODO: Implement getPluginId() method.
  }

  /**
   * {@inheritdoc}
   */
  public function getPluginDefinition() {
    // TODO: Implement getPluginDefinition() method.
  }

  /**
   * {@inheritdoc}
   */
  public function getEntityTypeId() {
    // TODO: Implement getEntityTypeId() method.
  }

  /**
   * {@inheritdoc}
   */
  public function apply(
    EntityInterface $entity,
    PromotionInterface $promotion
  ) {
    // TODO: Implement apply() method.
  }

}

==> affected_by_promotion-8.x-1.2.zip: affected_by_promotion/tests/src/Unit/DummyPromotionBase.php <==
<?php

namespace Drupal\Tests\affected_by_promotion\Unit;

use Drupal\commerce_promotion\Entity\PromotionInterface;
use Drupal\commerce_promotion\Plugin\Commerce\PromotionOffer\PromotionOfferInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class DummyPromotionBase.
 */
abstract class DummyPromotionBase implements PromotionOfferInterface {

  /**
   * {@inheritdoc}
   */
  public function getConfiguration() {
    // TODO: Implement getConfiguration() method.
  }

  /**
   * {@inheritdoc}
   */
  public function setConfiguration(array $configuration) {
    // TODO: Implement setConfiguration() method.
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    // TODO: Implement defaultConfiguration() method.
  }

  /**
   * {@inheritdoc}
   */
  public function calculateDependencies() {
    // TODO: Implement calculateDependencies() method.
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(
    array $form,
    FormStateInterface $form_state
  ) {
    // TODO: Implement buildConfigurationForm() method.
  }

  /**
   * {@inheritdoc}
   */
  public function validateConfigurationForm(
    array &$form,
    FormStateInterface $form_state
  ) {
    // TODO: Implement validateConfigurationForm() method.
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(
    array &$form,
    FormStateInterface $form_state
  ) {
    // TODO: Implement submitConfigurationForm() method.
  }

  /**
   * {@inheritdoc}
   */
  public function getPluginId() {
    // TODO: Implement getPluginId() method.
  }

  /**
   * {@inheritdoc}
   */
  public function getPluginDefinition() {
    // TODO: Implement getPluginDefinition() method.
  }

  /**
   * {@inheritdoc}
   */
  public function getEntityTypeId() {
    // TODO: Implement getEntityTypeId() method.
  }

  /**
   * {@inheritdoc}
   */
  public function apply(
    EntityInterface $entity,
    PromotionInterface $promotion
  ) {
    // TODO: Implement apply() method.
  }

  /**
   * {@inheritdoc}
   */
  public function clear(EntityInterface $entity, PromotionInterface $promotion) {
    // TODO: Implement clear() method.
  }

}
